@@ -322,16 +322,16 @@ impl UserFacingError {
     /// let mut err = UserFacingError::new("File failed to open");
     /// err.push("Failed Task");
     /// ```
-    pub fn push(&mut self, summary: &str) {
+    pub fn push(&mut self, new_summary: &str) {
         // Add the old summary to the list of reasons
         let old_summary = self.summary();
         match self.reasons.as_mut() {
             Some(reasons) => reasons.insert(0, old_summary),
-            None => self.reasons = Some(vec![summary.into()]),
+            None => self.reasons = Some(vec![old_summary.into()]),
         }
 
         // Update the summary
-        self.summary = summary.to_string();
+        self.summary = new_summary.to_string();
     }
 
     /// Add a reason to the UserFacingError. Reasons are displayed in a bulleted list below the summary, in the reverse order they were added.
@@ -422,7 +422,7 @@ mod tests {
             "{}{}{}\n{}{}{}\n",
             SUMMARY_PREFIX, S, RESET, HELPTEXT_PREFIX, H, RESET
         );
-        assert_eq!(e.to_string(), String::from(expected));
+        assert_eq!(e.to_string(), expected);
         eprintln!("{}", e);
     }
 
@@ -441,7 +441,7 @@ mod tests {
         let reasons = [&reason_strings.join("\n"), RESET].concat();
 
         let expected = format!("{}{}{}\n{}\n", SUMMARY_PREFIX, S, RESET, reasons);
-        assert_eq!(e.to_string(), String::from(expected));
+        assert_eq!(e.to_string(), expected);
         eprintln!("{}", e);
     }
 
@@ -451,7 +451,7 @@ mod tests {
         e.push("R2");
 
         /* Create Reasons String */
-        let reasons = vec![String::from("R2"), String::from("R1")];
+        let reasons = vec![String::from(S), String::from("R1")];
         let mut reason_strings = Vec::with_capacity(reasons.len());
         for reason in reasons {
             let bullet_point = [REASON_PREFIX, &reason].concat();
@@ -460,8 +460,28 @@ mod tests {
         /* Join the buller points with a newline, append a RESET ASCII escape code to the end */
         let reasons = [&reason_strings.join("\n"), RESET].concat();
 
-        let expected = format!("{}{}{}\n{}\n", SUMMARY_PREFIX, S, RESET, reasons);
-        assert_eq!(e.to_string(), String::from(expected));
+        let expected = format!("{}{}{}\n{}\n", SUMMARY_PREFIX, "R2", RESET, reasons);
+        assert_eq!(e.to_string(), expected);
+        eprintln!("{}", e);
+    }
+
+    #[test]
+    fn push_test_empty() {
+        let mut e = UserFacingError::new(S);
+        e.push("S2");
+
+        /* Create Reasons String */
+        let reasons = vec![String::from(S)];
+        let mut reason_strings = Vec::with_capacity(reasons.len());
+        for reason in reasons {
+            let bullet_point = [REASON_PREFIX, &reason].concat();
+            reason_strings.push(bullet_point);
+        }
+        /* Join the buller points with a newline, append a RESET ASCII escape code to the end */
+        let reasons = [&reason_strings.join("\n"), RESET].concat();
+
+        let expected = format!("{}{}{}\n{}\n", SUMMARY_PREFIX, "S2", RESET, reasons);
+        assert_eq!(e.to_string(), expected);
         eprintln!("{}", e);
     }
 
@@ -483,7 +503,7 @@ mod tests {
             "{}{}{}\n{}\n{}{}{}\n",
             SUMMARY_PREFIX, S, RESET, reasons, HELPTEXT_PREFIX, H, RESET
         );
-        assert_eq!(e.to_string(), String::from(expected));
+        assert_eq!(e.to_string(), expected);
         eprintln!("{}", e);
     }
 
